from distutils.core import setup

setup(

       name    = 'nestersru',
       version = '1.1.3',
       py_modules =['nestersru'],
       author = 'hfpython',
       author_email ='hfpython@headfirstlabs.com',
       url          = 'http://www.headfirstlabs.com',
       description   = 'A simple printer of nested lists',

       )
